@@ -27,7 +27,7 @@ Example usage:
 
 from .autocast import autocast, is_autocast_enabled, get_autocast_dtype
 from .grad_scaler import GradScaler
-from .utils import should_cast_to_fp16, maybe_cast_data
+from .utils import should_cast_to_fp16, maybe_cast_tensor
 
 # For backward compatibility and convenience
 __all__ = [
@@ -36,5 +36,5 @@ __all__ = [
     'is_autocast_enabled',
     'get_autocast_dtype',
     'should_cast_to_fp16',
-    'maybe_cast_data'
-]
+    'maybe_cast_tensor'
+]
\ No newline at end of file
