@@ -1,3 +1,4 @@
+import neurograd as ng
 from neurograd import xp
 from .base import Function
 from neurograd.nn.module import Module
@@ -12,18 +13,8 @@ class Add(Function, Module):
         return a + b
     def backward(self, grad_output: xp.ndarray) -> tuple[xp.ndarray, xp.ndarray]:
         a, b = self.parent_tensors
-        
-        if a.requires_grad:
-            go_a = self._cast_like(grad_output, a.data)
-            a_grad = self._handle_broadcasting(go_a, a.data.shape)
-        else:
-            a_grad = None
-        if b.requires_grad:
-            go_b = self._cast_like(grad_output, b.data)
-            b_grad = self._handle_broadcasting(go_b, b.data.shape)
-        else:
-            b_grad = None
-        
+        a_grad = self._handle_broadcasting(grad_output, a.shape) if a.requires_grad else None
+        b_grad = self._handle_broadcasting(grad_output, b.shape) if b.requires_grad else None
         return a_grad, b_grad
 
 class Sub(Function, Module):
@@ -35,23 +26,13 @@ class Sub(Function, Module):
         return a - b
     def backward(self, grad_output: xp.ndarray) -> tuple[xp.ndarray, xp.ndarray]:
         a, b = self.parent_tensors
-        
-        if a.requires_grad:
-            go_a = self._cast_like(grad_output, a.data)
-            a_grad = self._handle_broadcasting(go_a, a.data.shape)
-        else:
-            a_grad = None
-        if b.requires_grad:
-            go_b = self._cast_like(-grad_output, b.data)
-            b_grad = self._handle_broadcasting(go_b, b.data.shape)
-        else:
-            b_grad = None
-        
+        a_grad = self._handle_broadcasting(grad_output, a.shape) if a.requires_grad else None
+        b_grad = self._handle_broadcasting(-grad_output, b.shape) if b.requires_grad else None
         return a_grad, b_grad
 
 class Mul(Function, Module):
-    name = "Mul"
     """Element-wise multiplication."""
+    name = "Mul"
     def __init__(self):
         Function.__init__(self)
         Module.__init__(self)
@@ -59,23 +40,16 @@ class Mul(Function, Module):
         return a * b
     def backward(self, grad_output: xp.ndarray) -> tuple[xp.ndarray, xp.ndarray]:
         a, b = self.parent_tensors
-        
-        if a.requires_grad:
-            go = self._cast_like(grad_output, b.data)
-            a_grad = self._handle_broadcasting(go * b.data, a.data.shape)
-        else:
-            a_grad = None
-        if b.requires_grad:
-            go = self._cast_like(grad_output, a.data)
-            b_grad = self._handle_broadcasting(go * a.data, b.data.shape)
-        else:
-            b_grad = None
-        
+        a_grad = self._handle_broadcasting(grad_output * b.data, a.shape) if a.requires_grad else None
+        b_grad = self._handle_broadcasting(grad_output * a.data, b.shape) if b.requires_grad else None
         return a_grad, b_grad
 
 class Div(Function, Module):
-    name = "Div"
     """Element-wise division."""
+    name = "Div"
+    @ng.fuse
+    def _fused_bw_b(grad_output, a, b):
+        return -grad_output * a / (b ** 2)
     def __init__(self):
         Function.__init__(self)
         Module.__init__(self)
@@ -83,23 +57,20 @@ class Div(Function, Module):
         return a / b
     def backward(self, grad_output: xp.ndarray) -> tuple[xp.ndarray, xp.ndarray]:
         a, b = self.parent_tensors
-        
-        if a.requires_grad:
-            go = self._cast_like(grad_output, b.data)
-            a_grad = self._handle_broadcasting(go / b.data, a.data.shape)
-        else:
-            a_grad = None
-        if b.requires_grad:
-            go = self._cast_like(grad_output, a.data)
-            b_grad = self._handle_broadcasting(-go * a.data / (b.data ** 2), b.data.shape)
-        else:
-            b_grad = None
-        
-        return a_grad, b_grad
+        a_grad = grad_output / b.data if a.requires_grad else None
+        b_grad = Div._fused_bw_b(grad_output, a.data, b.data) if b.requires_grad else None
+        return (self._handle_broadcasting(a_grad, a.shape), 
+                self._handle_broadcasting(b_grad, b.shape))
 
 class Pow(Function, Module):
     name = "Pow"
     """Element-wise power."""
+    @ng.fuse
+    def _fused_bw_a(grad_output, a, b):
+        return grad_output * b * a ** (b - 1)
+    @ng.fuse
+    def _fused_bw_b(grad_output, a, b):
+        return grad_output * xp.log(a) * (a ** b)
     def __init__(self):
         Function.__init__(self)
         Module.__init__(self)
@@ -107,20 +78,10 @@ class Pow(Function, Module):
         return a ** b
     def backward(self, grad_output: xp.ndarray) -> tuple[xp.ndarray, xp.ndarray]:
         a, b = self.parent_tensors
-        
-        if a.requires_grad:
-            go = self._cast_like(grad_output, a.data)
-            a_grad = self._handle_broadcasting(go * b.data * a.data ** (b.data - 1), a.data.shape)
-        else:
-            a_grad = None
-        if b.requires_grad:
-            go = self._cast_like(grad_output, b.data)
-            b_grad = self._handle_broadcasting(go * xp.log(a.data) * (a.data ** b.data), b.data.shape)
-        else:
-            b_grad = None
-        
-        return a_grad, b_grad
-    
+        a_grad = Pow._fused_bw_a(grad_output, a.data, b.data) if a.requires_grad else None
+        b_grad = Pow._fused_bw_b(grad_output, a.data, b.data) if b.requires_grad else None
+        return (self._handle_broadcasting(a_grad, a.shape), 
+                self._handle_broadcasting(b_grad, b.shape))
 
 # Convenience functions for arithmetic operations
 # These functions are designed to be used directly with Tensor objects.
@@ -133,4 +94,4 @@ def mul(a, b):
 def div(a, b):
     return Div()(a, b)
 def pow(a, b):
-    return Pow()(a, b)
+    return Pow()(a, b)
\ No newline at end of file
