@@ -1,10 +1,11 @@
-from neurograd.functions.activations import ReLU, LeakyReLU, Sigmoid, Softmax, Tanh, Passthrough
+from neurograd.functions.activations import ReLU, LeakyReLU, ReLU6, Sigmoid, Softmax, Tanh, Passthrough
 from neurograd.nn.losses import MSE, RMSE, MAE, BinaryCrossEntropy, CategoricalCrossEntropy
 from neurograd.nn.initializers import Xavier, He, Zeros, Normal
 
 ACTIVATIONS = {
     "relu": lambda: ReLU(),
     "leaky_relu": lambda: LeakyReLU(),
+    "relu6": lambda: ReLU6(),
     "sigmoid": lambda: Sigmoid(),
     "softmax": lambda: Softmax(),
     "tanh": lambda: Tanh(),
@@ -26,4 +27,4 @@ INITIALIZERS = {
     "he": He,
     "zeros": Zeros,
     "normal": Normal
-}
\ No newline at end of file
+}
